@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -125,7 +125,7 @@ function add_tree_names_to_actions_array() {
 
 	if (sizeof($trees)) {
 		foreach ($trees as $tree) {
-			$graph_actions{'tr_' . $tree['id']} = __('Place on a Tree (%s)', $tree['name']);
+			$graph_actions['tr_' . $tree['id']] = __('Place on a Tree (%s)', $tree['name']);
 		}
 	}
 }
@@ -262,20 +262,24 @@ function form_save() {
 			}
 		}
 
-		$lg_template_id = db_fetch_cell_prepared('SELECT graph_template_id
-			FROM graph_local
-			WHERE id = ?',
-			array($local_graph_id));
-
-		$lg_dq_id = db_fetch_cell_prepared('SELECT snmp_query_id
-			FROM graph_lcoal
-			WHERE id = ?',
-			array($local_graph_id));
-
 		if (!is_error_message()) {
+			$lg_template_id = db_fetch_cell_prepared(
+				'SELECT graph_template_id
+				 FROM graph_local
+				 WHERE id = ?',
+				array($local_graph_id)
+			);
+
 			if ($lg_template_id > 0) {
 				change_graph_template($local_graph_id, $gt_id_unparsed);
 
+				$lg_dq_id = db_fetch_cell_prepared(
+					'SELECT snmp_query_id
+					 FROM graph_local
+					 WHERE id = ?',
+					array($local_graph_id)
+				);
+
 				if ($lg_dq_id > 0) {
 					update_graph_data_query_cache($local_graph_id);
 				}
@@ -1431,9 +1435,9 @@ function graph_edit() {
 					$graph_data_array['print_source'] = 1;
 					?>
 					<td>
-						<span class='textInfo'><?php print __('RRDTool Command:');?></span><br>
+						<span class='textInfo'><?php print __('RRDtool Command:');?></span><br>
 						<pre><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
-						<span class='textInfo'><?php print __('RRDTool Says:');?></span><br>
+						<span class='textInfo'><?php print __('RRDtool Says:');?></span><br>
 						<?php unset($graph_data_array['print_source']);?>
 						<pre><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
 					</td>
@@ -1521,17 +1525,26 @@ function graph_edit() {
 
 			$('body').append("<div id='modal' class='ui-widget-overlay ui-front' style='z-index: 100;'><i style='position:absolute;top:50%;left:50%;' class='fa fa-spin fa-circle-o-notch'/></div>");
 
-			$.get('graphs.php?action=unlock&header=false&id='+$('#local_graph_id').val(), function(data) {
-				$('#modal').remove();
-				$('#main').html(data);
-				applySkin();
-			});
+			$.get('graphs.php?action=unlock&header=false&id='+$('#local_graph_id').val())
+				.done(function(data) {
+					$('#modal').remove();
+					$('#main').html(data);
+					applySkin();
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
 		});
 
-		$.getJSON(imageSource, function(data) {
-			$('#graphLocation').html("<img class='cactiGraphImage' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
-			$(window).trigger('resize');
-		});
+		$.getJSON(imageSource)
+			.done(function(data) {
+				$('#graphLocation').html("<img class='cactiGraphImage' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
+				$(window).trigger('resize');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
+
 
 		$('#lockid').click(function(event) {
 			event.preventDefault;
@@ -1639,11 +1652,12 @@ function graph_management() {
 	<script type='text/javascript'>
 
 	function applyFilter() {
-		strURL  = 'graphs.php?host_id=' + $('#host_id').val();
-		strURL += '&rows=' + $('#rows').val();
-		strURL += '&rfilter=' + $('#rfilter').val();
-		strURL += '&template_id=' + $('#template_id').val();
-		strURL += '&header=false';
+		strURL  = 'graphs.php' +
+			'?host_id=' + $('#host_id').val() +
+			'&rows=' + $('#rows').val() +
+			'&rfilter=' + base64_encode($('#rfilter').val()) +
+			'&template_id=' + $('#template_id').val() +
+			'&header=false';
 		loadPageNoHeader(strURL);
 	}
 
@@ -1810,7 +1824,7 @@ function graph_management() {
 		$sql_order
 		$sql_limit");
 
-	$nav = html_nav_bar('graphs.php?rfilter=' . get_request_var('rfilter') . '&host_id=' . get_request_var('host_id'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 5, 'Graphs', 'page', 'main');
+	$nav = html_nav_bar('graphs.php?rfilter=' . get_request_var('rfilter') . '&host_id=' . get_request_var('host_id'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 5, __('Graphs'), 'page', 'main');
 
 	form_start('graphs.php', 'chk');
 
