@@ -52,25 +52,23 @@ function dsstats_get_and_store_ds_avgpeak_values($interval) {
 	$rrdfiles = get_rrdfile_names();
 	$stats    = array();
 
-	$process_pipes = dsstats_rrdtool_init();
-	$process = $process_pipes[0];
-	$pipes   = $process_pipes[1];
+	/* open a pipe to rrdtool for writing */
+	$rrdtool_pipe = rrd_init();
 
 	if (sizeof($rrdfiles)) {
-	foreach ($rrdfiles as $file) {
-		if ($file['data_source_path'] != '') {
-			$rrdfile = str_replace('<path_rra>', $config['rra_path'], $file['data_source_path']);
+		foreach ($rrdfiles as $file) {
+			if ($file['data_source_path'] != '') {
+				$rrdfile = str_replace('<path_rra>', $config['rra_path'], $file['data_source_path']);
 
-			$stats[$file['local_data_id']] = dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $pipes);
-		} else {
-			$data_source_name = db_fetch_cell_prepared('SELECT name_cache FROM data_template_data WHERE local_data_id = ?', array($file['local_data_id']));
-			cacti_log("WARNING: Data Source '$data_source_name' is damaged and contains no path.  Please delete and re-create both the Graph and Data Source.", false, 'DSSTATS');
+				$stats[$file['local_data_id']] = dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool_pipe);
+			} else {
+				$data_source_name = db_fetch_cell_prepared('SELECT name_cache FROM data_template_data WHERE local_data_id = ?', array($file['local_data_id']));
+				cacti_log("WARNING: Data Source '$data_source_name' is damaged and contains no path.  Please delete and re-create both the Graph and Data Source.", false, 'DSSTATS');
+			}
 		}
 	}
-	}
-
-	dsstats_rrdtool_close($process);
 
+	rrd_close($rrdtool_pipe);
 	dsstats_write_buffer($stats, $interval);
 }
 
@@ -130,80 +128,6 @@ function dsstats_write_buffer(&$stats_array, $interval) {
 	}
 }
 
-/* dsstats_rrdtool_init - this routine provides a bi-directional socket based connection to RRDtool.
-     it provides a high speed connection to rrdfile in the case where the traditional Cacti call does
-     not when performing fetch type calls.
-   @returns - (mixed) An array that includes both the process resource and the pipes to communicate
-     with RRDtool. */
-function dsstats_rrdtool_init() {
-	global $config;
-
-	if ($config['cacti_server_os'] == 'unix') {
-		$fds = array(
-			0 => array('pipe', 'r'), // stdin
-			1 => array('pipe', 'w'), // stdout
-			2 => array('file', '/dev/null', 'a')  // stderr
-		);
-	} else {		$fds = array(
-			0 => array('pipe', 'r'), // stdin
-			1 => array('pipe', 'w'), // stdout
-			2 => array('file', 'nul', 'a')  // stderr
-		);
-	}
-
-	/* set the rrdtool default font */
-	if (read_config_option('path_rrdtool_default_font')) {
-		putenv('RRD_DEFAULT_FONT=' . read_config_option('path_rrdtool_default_font'));
-	}
-
-	$command = read_config_option('path_rrdtool') . ' - ';
-
-	$process = proc_open($command, $fds, $pipes);
-
-	/* make stdin/stdout/stderr non-blocking */
-	stream_set_blocking($pipes[0], 0);
-	stream_set_blocking($pipes[1], 0);
-
-	return array($process, $pipes);
-}
-
-/* dsstats_rrdtool_execute - this routine passes commands to RRDtool and returns the information
-     back to DSStats.  It is important to note here that RRDtool needs to provide an either 'OK'
-     or 'ERROR' response accross the pipe as it does not provide EOF characters to key upon.
-     This may not be the best method and may be changed after I have a conversation with a few
-     developers.
-   @arg $command - (string) The rrdtool command to execute
-   @arg $pipes - (array) An array of stdin and stdout pipes to read and write data from
-   @returns - (string) The output from RRDtool */
-function dsstats_rrdtool_execute($command, $pipes) {
-	$stdout = '';
-
-	if ($command == '') return;
-
-	$command .= "\r\n";
-
-	$return_code = fwrite($pipes[0], $command);
-
-	while (!feof($pipes[1])) {
-		$stdout .= fgets($pipes[1], 4096);
-		if (substr_count($stdout, 'OK')) {
-			break;
-		}
-		if (substr_count($stdout, 'ERROR')) {
-			break;
-		}
-	}
-
-	if (strlen($stdout)) return $stdout;
-}
-
-/* dsstats_rrdtool_close - this routine closes the RRDtool process thus also
-     closing the pipes.
-   @returns - NULL */
-function dsstats_rrdtool_close($process) {
-	proc_close($process);
-}
-
 /* dsstats_obtain_data_source_avgpeak_values - this routine, given the rrdfile name, interval and RRDtool process
      pipes, will obtain the average a peak values from the RRDfile.  It does this in two steps:
 
@@ -218,17 +142,19 @@ function dsstats_rrdtool_close($process) {
      components and then calculates the AVERAGE and MAX values from that data and returns an array to the calling
      function for storage into the respective database table.
    @returns - (mixed) An array of AVERAGE, and MAX values in an RRDfile by Data Source name */
-function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $pipes) {
+function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool_pipe) {
 	global $config;
 
+	if (read_config_option('storage_location')) {
+		$file_exists = rrdtool_execute("file_exists $rrdfile", true, RRDTOOL_OUTPUT_BOOLEAN, $rrdtool_pipe, 'DSSTATS');
+	}else {
+		$file_exists = file_exists($rrdfile);
+	}
+
 	/* don't attempt to get information if the file does not exist */
-	if (file_exists($rrdfile)) {
+	if ($file_exists) {
 		/* high speed or snail speed */
-		if (read_config_option('dsstats_rrdtool_pipe') == 'on') {
-			$info = dsstats_rrdtool_execute("info $rrdfile", $pipes);
-		} else {
-			$info = rrdtool_execute("info $rrdfile", false, RRDTOOL_OUTPUT_STDOUT);
-		}
+		$info = rrdtool_execute("info $rrdfile", false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'DSSTATS');
 
 		/* don't do anything if RRDfile did not return data */
 		if ($info != '') {
@@ -316,11 +242,7 @@ function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $pipes)
 
 			/* now execute the xport command */
 			$xport_cmd = 'xport --start now-1' . $interval . ' --end now ' . trim($def) . ' ' . trim($xport) . ' --maxrows 10';
-			if (read_config_option('dsstats_rrdtool_pipe') == 'on') {
-				$xport_data = dsstats_rrdtool_execute($xport_cmd, $pipes);
-			} else {
-				$xport_data = rrdtool_execute($xport_cmd, false, RRDTOOL_OUTPUT_STDOUT);
-			}
+			$xport_data = rrdtool_execute($xport_cmd, false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'DSSTATS');
 
 			/* initialize the array of return values */
 			foreach($dsnames as $dsname => $present) {
